@@ -3,9 +3,9 @@ import numpy as np
 import pandas as pd
 import datetime as dt
 
-import agg
-from categorical_analysis import get_transmat, synthetic_states_from_transmat
-from util import holm_bonferroni_correction, split_to_contiguous, is_time_type, make_all_dims_coords, drop_scalar_coords, squeeze_da
+from domino import agg
+from domino.categorical_analysis import get_transmat, synthetic_states_from_transmat
+from domino.util import holm_bonferroni_correction, split_to_contiguous, is_time_type, make_all_dims_coords, drop_scalar_coords, squeeze_da
 
 
 class LaggedAnalyser(object):
